@@ -1,20 +1,19 @@
-# $Id$
+# $Id: SimpleLinkExtor.pm 2225 2007-03-19 05:22:52Z comdog $
 package HTML::SimpleLinkExtor;
 use strict;
 
-use warnings;
-no warnings;
-
 use subs qw();
-use vars qw($VERSION @ISA %AUTO_METHODS $AUTOLOAD );
+use vars qw($VERSION @ISA %AUTO_METHODS $AUTOLOAD $DEBUG);
 
 use AutoLoader;
 use Carp qw(carp);
 use HTML::LinkExtor;
-use LWP::UserAgent;
 use URI;
 
-$VERSION = '1.21_02';
+$VERSION = 1.17;
+#sprintf "%d.%02d", q$Revision: 2225 $ =~ m/ (\d+) \. (\d+) /xg;
+
+$DEBUG   = 0;
 
 @ISA = qw(HTML::LinkExtor);
 
@@ -34,15 +33,86 @@ $VERSION = '1.21_02';
 	script	tag
 	);
 
+sub new
+	{
+	my $class = shift;
+	my $base  = shift;
+
+	my $self = new HTML::LinkExtor;
+	bless $self, $class;
+
+	$self->{'_SimpleLinkExtor_base'} = $base;
+	$self->_init_links;
+	
+	return $self;
+	}
 
 sub DESTROY { 1 };
 
+sub add_attributes
+	{
+	my $self = shift;
+	my $attr = lc shift;
+	
+	$AUTO_METHODS{ $attr } = 'attribute';
+	}
+	
+sub add_tags
+	{
+	my $self = shift;
+	my $tag  = lc shift;
+	
+	$AUTO_METHODS{ $tag } = 'tag';
+	}
+
+sub remove_attributes
+	{
+	my $self = shift;
+	my $attr = lc shift;
+	
+	delete $AUTO_METHODS{ $attr };
+	}
+	
+sub remove_tags
+	{
+	my $self = shift;
+	my $tag  = lc shift;
+	
+	delete $AUTO_METHODS{ $tag };
+	}
+
+sub attribute_list
+	{
+	my $self = shift;
+	
+	grep { $AUTO_METHODS{ $_ } eq 'attribute' } keys %AUTO_METHODS;
+	}
+	
+sub tag_list
+	{
+	my $self = shift;
+	
+	grep { $AUTO_METHODS{ $_ } eq 'tag' } keys %AUTO_METHODS;
+	}
+
+sub clear_links { $_[0]->_init_links }
+
+sub links
+	{
+	my $self = shift;
+
+	return map { $$_[2] } $self->_link_refs;
+	}
+
+sub frames { ( $_[0]->frame, $_[0]->iframe ) }
+
 sub AUTOLOAD
 	{
 	my $self = shift;
 	my $method = $AUTOLOAD;
 
 	$method =~ s/.*:://;
+	print STDERR "AUTOLOAD: method is $method\n" if $DEBUG;
 
 	unless( exists $AUTO_METHODS{$method} )
 		{
@@ -50,31 +120,10 @@ sub AUTOLOAD
 		return;
 		}
 
+	print STDERR "AUTOLOAD: calling _extract\n" if $DEBUG;
 	$self->_extract( $method );
 	}
 
-sub can
-	{
-	my( $self, @methods ) = @_;
-
-	foreach my $method ( @methods )
-		{
-		return 0 unless $self->_can( $method );
-		}
-
-	return 1;
-	}
-	
-sub _can
-	{
-	no strict 'refs';
-
-	return 1 if exists $AUTO_METHODS{ $_[1] };
-	return 1 if defined &{"$_[1]"};
-	
-	return 0;
-	}
-	
 sub _init_links
 	{
 	my $self  = shift;
@@ -129,8 +178,9 @@ sub _link_refs
 		#splice @link_refs, $count, 1, () if $found;
 		}
 
-	$self->_add_base(\@link_refs);
+	$self->_add_base(\@link_refs) if $self->{'_SimpleLinkExtor_base'};
 
+	print "_link_refs: there are $#link_refs + 1 links\n" if $DEBUG;
 	return @link_refs;
 	}
 
@@ -140,11 +190,13 @@ sub _extract
 	my $method    = shift;
 
 	my $position  = $AUTO_METHODS{$method} eq 'tag' ? 0 : 1;
+	print "_extract: Position is $position\n" if $DEBUG;
 
 	my @links = map  { $$_[2] }
 	            grep { $_->[$position] eq $method }
 	            $self->_link_refs;
 
+	print "_extract: There are $#links + 1 links\n" if $DEBUG;
 	return @links;
 	}
 
@@ -154,7 +206,7 @@ sub _add_base
 	my $array_ref = shift;
 
 	my $base      = $self->{'_SimpleLinkExtor_base'};
-	return unless $base;
+	next unless $base;
 	
 	foreach my $tuple ( @$array_ref )
 		{
@@ -169,6 +221,22 @@ sub _add_base
 		}
 	}
 
+sub parse_url
+	{
+	my $self = shift;
+	my $url  = shift;
+	
+	require LWP::Simple;
+	
+	my $data = LWP::Simple::get( $url );
+	
+	return unless defined $data;
+	
+	$self->parse( $data );
+	}
+	
+1;
+__END__
 =head1 NAME
 
 HTML::SimpleLinkExtor - Extract links from HTML
@@ -205,8 +273,6 @@ HTML::SimpleLinkExtor - Extract links from HTML
 	@body_bg     = $extor->body;
 	@background  = $extor->background;
 
-	@links       = $extor->scheme( 'http' );
-	
 =head1 DESCRIPTION
 
 This is a simple HTML link extractor designed for the person who does
@@ -244,31 +310,6 @@ any other base URL found in the HTML.
 Create the link extractor object and do not resolve relative
 links.
 
-=cut
-
-sub new
-	{
-	my $class = shift;
-	my $base  = shift;
-
-	my $self = new HTML::LinkExtor;
-	bless $self, $class;
-
-	$self->{'_SimpleLinkExtor_base'} = $base;
-	$self->{'_ua'} = LWP::UserAgent->new;
-	$self->_init_links;
-	
-	return $self;
-	}
-
-=item HTML::SimpleLinkExtor->ua;
-
-Returns the internal user agent, an C<LWP::UserAgent> object.
-
-=cut
-
-sub ua { $_[0]->{_ua} }
-
 =item HTML::SimpleLinkExtor->add_tags( TAG [, TAG ] )
 
 C<HTML::SimpleLinkExtor> keeps an internal list of HTML tags (such as
@@ -277,16 +318,6 @@ that this module doesn't handle, please send it to me and I'll add it.
 Until then you can add that tag to the internal list. This affects
 the entire class, including previously created objects.
 
-=cut
-
-sub add_tags
-	{
-	my $self = shift;
-	my $tag  = lc shift;
-	
-	$AUTO_METHODS{ $tag } = 'tag';
-	}
-
 =item HTML::SimpleLinkExtor->add_attributes( ATTR [, ATTR] )
 
 C<HTML::SimpleLinkExtor> keeps an internal list of HTML tag attributes
@@ -296,149 +327,64 @@ me and I'll add it. Until then you can add that attribute to the
 internal list. This affects the entire class, including previously
 created objects.
 
-=cut
-
-=item can()
-
-A smarter C<can> that can tell which attributes are also methods.
-
-=cut
-
-sub add_attributes
-	{
-	my $self = shift;
-	my $attr = lc shift;
-	
-	$AUTO_METHODS{ $attr } = 'attribute';
-	}
-	
 =item HTML::SimpleLinkExtor->remove_tags( TAG [, TAG ] )
 
 Take tags out of the internal list that C<HTML::SimpleLinkExtor> uses
 to extract URLs. This affects the entire class, including previously
 created objects.
 
-=cut
-
-sub remove_tags
-	{
-	my $self = shift;
-	my $tag  = lc shift;
-	
-	delete $AUTO_METHODS{ $tag };
-	}
-
 =item HTML::SimpleLinkExtor->remove_attributes( ATTR [, ATTR] )
 
 Takes attributes out of the internal list that
 C<HTML::SimpleLinkExtor> uses to extract URLs. This affects the entire
 class, including previously created objects.
 
-=cut
-
-sub remove_attributes
-	{
-	my $self = shift;
-	my $attr = lc shift;
-	
-	delete $AUTO_METHODS{ $attr };
-	}
-
 =item HTML::SimpleLinkExtor->attribute_list
 
 Returns a list of the attributes C<HTML::SimpleLinkExtor> pays
 attention to.
 
-=cut
-
-sub attribute_list
-	{
-	my $self = shift;
-	
-	grep { $AUTO_METHODS{ $_ } eq 'attribute' } keys %AUTO_METHODS;
-	}
-
 =item HTML::SimpleLinkExtor->tag_list
 
 Returns a list of the tags C<HTML::SimpleLinkExtor> pays attention to.
 
 =back
 
-=cut
-
-sub tag_list
-	{
-	my $self = shift;
-	
-	grep { $AUTO_METHODS{ $_ } eq 'tag' } keys %AUTO_METHODS;
-	}
-
 =head2 Object methods
 
 =over 4
 
 =item $extor->parse_file( $filename )
 
-Parse the file for links. Inherited from C<HTML::Parser>.
+Parse the file for links.
 
-=cut
-
-
-=item $extor->parse_url( $url [, $ua] )
+=item $extor->parse_url( $url )
 
 Fetch URL and parse its content for links.
 
-=cut
-
-sub parse_url
-	{
-	my $data = $_[0]->ua->get( $_[1] )->content;
-		
-	return unless $data;
-	
-	$_[0]->parse( $data );
-	}
-
 =item $extor->parse( $data )
 
-Parse the HTML in C<$data>. Inherited from C<HTML::Parser>.
+Parse the HTML in C<$data>.
 
 =item $extor->clear_links
 
 Clear the link list. This way, you can use the same parser for
 another file.
 
-=cut
-
-sub clear_links { $_[0]->_init_links }
-
 =item $extor->links
 
 Return a list of the links.
 
-=cut
-
-sub links
-	{
-	return map { $$_[3] } $_[0]->_link_refs;
-	}
-
 =item $extor->img
 
 Return a list of the links from all the SRC attributes of the
 IMG.
 
-=cut
-
 =item $extor->frame
 
 Return a list of all the links from all the SRC attributes of
 the FRAME.
 
-=cut
-
-sub frames { ( $_[0]->frame, $_[0]->iframe ) }
-
 =item $extor->iframe
 
 Return a list of all the links from all the SRC attributes of
@@ -481,88 +427,6 @@ Return the link from the BODY tag's BACKGROUND attribute.
 
 Return the link from the SCRIPT tag's SRC attribute
 
-=item $extor->schemes( SCHEME, [ SCHEME, ... ] )
-
-Return the links that use any of SCHEME. These must be absolute URLs (which
-might include those converted to absolute URLs by specifying a
-base). SCHEME is case-insensitive. You can specify more than one
-scheme.
-
-In list context it returns the links. In scalar context it returns
-the count of the matching links.
-
-=cut
-
-sub schemes
-	{
-	my( $self, @schemes ) = @_;
-	
-	my %schemes;
-	
-	@schemes{@schemes} = lc @schemes;
-	
-	my @links = 
-		grep { 
-			my $scheme = eval { lc URI->new( $_ )->scheme };  
-			exists $schemes{ $scheme };
-			}
-		map { $$_[2] } 
-			$self->_link_refs;
-			
-	wantarray ? @links : scalar @links;
-	}
-
-=item $extor->absolute_links
-
-Returns the absolute URLs (which might include those converted to
-absolute URLs by specifying a base).
-
-In list context it returns the links. In scalar context it returns
-the count of the matching links.
-
-=cut	
-
-sub absolute_links
-	{
-	my $self = shift;
-		
-	my @links = 
-		grep { 
-			my $scheme = eval { lc URI->new( $_ )->scheme };  
-			length $scheme;
-			}
-		map { $$_[2] } 
-			$self->_link_refs;
-	
-	wantarray ? @links : scalar @links;
-	}
-	
-=item $extor->relative_links
-
-Returns the relatives URLs (which might exclude those converted to
-absolute URLs by specifying a base or having a base in the document).
-
-In list context it returns the links. In scalar context it returns
-the count of the matching links.
-
-
-=cut 
-
-sub relative_links
-	{
-	my $self = shift;
-		
-	my @links = 
-		grep { 
-			my $scheme = eval { URI->new( $_ )->scheme }; 
-			! defined $scheme;
-			}
-		map { $$_[2] } 
-			$self->_link_refs;
-	
-	wantarray ? @links : scalar @links;
-	}
-
 =back
 
 =head1 TO DO
@@ -579,7 +443,7 @@ a USEMAP attribute.
 =head1 SOURCE AVAILABILITY
 
 This source is part of a SourceForge project which always has the
-latest sources in SVN, as well as all of the previous releases.
+latest sources in CVS, as well as all of the previous releases.
 
 	http://sourceforge.net/projects/brian-d-foy/
 
@@ -600,5 +464,3 @@ it under the same terms as Perl itself.
 =cut
 
 1;
-
-__END__
